@@ -14,6 +14,7 @@ extensions = [
     'sphinx.ext.intersphinx',  # cross-references
     'sphinx.ext.todo',         # .. todo:: items
     'sphinx.ext.viewcode',     # show code samples
+    'sphinx_rtd_theme',
 ]
 
 # sort API documentation by source, not alphabetically
@@ -50,22 +51,7 @@ pygments_style = 'sphinx'
 todo_include_todos = True
 
 # -- Options for HTML output ----------------------------------------------
-html_theme = 'default'
-
-# on_rtd is whether we are on readthedocs.org, this line of code
-# grabbed from docs.readthedocs.org
-on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
-
-# would prefer alabaster theme because it is visually lighter, but it
-# doesn't support arbitrary source links:
-# https://github.com/bitprophet/alabaster/issues/87
-if not on_rtd:  # only import and set the theme if we're building docs locally
-    try:
-        import sphinx_rtd_theme
-        html_theme = 'sphinx_rtd_theme'
-        html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
-    except ImportError:  # nosec
-        pass
+html_theme = 'sphinx_rtd_theme'
 
 # link to original source instead of embedded
 html_context = {
