@@ -35,7 +35,6 @@ import os.path
 import feedparser
 import requests
 import requests_file
-from pkg_resources import parse_version
 from requests.adapters import HTTPAdapter
 
 import feed2exec
@@ -50,8 +49,9 @@ from feed2exec.model import (
 
 try:
     import cachecontrol
+    cachecontrol_enabled = True
 except ImportError:
-    cachecontrol = None
+    cachecontrol_enabled = False
 
 try:
     import dateparser
@@ -78,16 +78,8 @@ class FeedManager(object):
         self.db_path = db_path
         self.conf_storage = FeedConfStorage(self.conf_path, pattern=pattern)
         if dateparser_enabled:
-            if parse_version(dateparser.__version__) >= parse_version('0.7.4'):
-                def dateparser_tuple_parser(string):
-                    return dateparser.parse(string).utctimetuple()
-            else:
-                # workaround bug https://github.com/scrapinghub/dateparser/issues/548
-                def dateparser_tuple_parser(string):
-                    if string.endswith('-0000'):
-                        # replace the last '-0000' with '+0000' by reversing the string twice
-                        string = string[::-1].replace('-0000'[::-1], '+0000'[::-1], 1)[::-1]
-                    return dateparser.parse(string).utctimetuple()
+            def dateparser_tuple_parser(string):
+                return dateparser.parse(string).utctimetuple()
             feedparser.registerDateHandler(dateparser_tuple_parser)
 
         self._session = session or requests.Session()
@@ -112,7 +104,7 @@ class FeedManager(object):
                                       % (feed2exec.__prog__,
                                          feed2exec.__version__)})
         self._session.mount('file://', requests_file.FileAdapter())
-        if self.db_path is None or cachecontrol is None:
+        if not cachecontrol_enabled or self.db_path is None:
             return
         if not cache:
             # reset the session adapters to *not* use an eventual cache controller
