@@ -104,7 +104,7 @@ def test_relative_conf(tmpdir):
 
 
 def test_parse(feed_manager):
-    runner = CliRunner()
+    runner = CliRunner(mix_stderr=False)
     result = runner.invoke(main, ['parse',
                                   '--output', 'feed2exec.plugins.echo',
                                   '--args', 'foo bar',
@@ -211,7 +211,9 @@ def test_planet(tmpdir_factory, static_boundary, feed_manager):
                            catch_exceptions=False)
     assert 0 == result.exit_code
     r = re.compile('User-Agent: .*$', flags=re.MULTILINE)
-    with open(utils.find_test_file('../cassettes/planet-debian.mbx')) as expected:
+    expected_path = utils.find_test_file('../cassettes/planet-debian.mbx')
+    actual_path = mbox_dir.join('planet-debian.mbx')
+    with open(expected_path) as expected:
         expected = r.sub('', expected.read())
-        actual = r.sub('', mbox_dir.join('planet-debian.mbx').read())
-        assert expected == actual
+        actual = r.sub('', actual_path.read())
+        assert expected == actual, "%s different from expected %s" % (expected_path, str(actual_path))
